#!/bin/sh

if [ $# -ne 1 ]; then
	echo "USAGE: <log file name>" >> stderr
	return 3
fi

log_file="$1"

which lpinfo >/dev/null
if [ $? -ne 0 ]; then
	echo "lpinfo command not found" >> ${log_file}
	exit 1;
fi

which lpadmin >/dev/null
if [ $? -ne 0 ]; then
	echo "lpadmin command not found" >> ${log_file}
	exit 1;
fi

which lpstat >/dev/null
if [ $? -ne 0 ]; then
	echo "lpstat command not found" >> ${log_file}
	exit 1;
fi

list=`lpinfo -v`

list=`lpinfo -v | grep -i usb | tr ' ' '@'`
if [ $? -ne 0 ]; then
	echo "\"lpinfo -v | grep -i usb\" command failed" >> ${log_file}
	exit 1;
fi
echo "List of USB devices = $list" >> ${log_file}

if [ -z "$list" ]; then
	echo "No printer attached" >> ${log_file}
	exit 2
fi

flag=0
for i in $list
do
	#echo "#####################################"
	usb=`echo $i | tr '@' ' '`
	echo "USB = $usb" >> ${log_file}
	serialNum=`echo $usb | awk -F"=" '{print $2}' | awk -F"&" '{print $1}'`
	echo "SerialNum - $serialNum" >> ${log_file}
	name=`echo $usb | awk -F"/" '{print $4}' | awk -F"%" '{print $1}' | awk -F"?" '{print $1}'`
	echo "Name - $name" >> ${log_file}

	uri=`echo $usb | awk -F" " '{print $NF}'`
	echo "URI - $uri" >> ${log_file}

	ret=`lpinfo -m | grep -i lsb | grep -iw $name`
	if [ $? -ne 0 ]; then
		ret=`lpinfo -m | grep -iw $name`
		if [ $? -ne 0 ]; then
			shortname=`echo $name | cut -c 1-5`
            echo "Short Name - $shortname" >> ${log_file}
            ret=`lpinfo -m | grep -i lsb | grep -i $shortname`
			if [ $? -ne 0 ]; then
				echo "Driver is not installed for $i" >> ${log_file}
				exit 1;
			fi
		fi
	fi
	echo "Ret - $ret" >> ${log_file}

	driver=`echo $ret | head -1 | awk -F" " '{print $1}'`	
	echo "Driver - $driver" >> ${log_file}

	if [ -z "$serialNum" ]; then
		qName="`echo $ret | head -1 | awk -F"/" '{print $NF}' | awk -F"." '{print $1}'`"
	else
		qName="`echo $ret | head -1 | awk -F"/" '{print $NF}' | awk -F"." '{print $1}'`_$serialNum"
	fi
	echo "Qname - $qName" >> ${log_file}

	existingQ=`lpstat -t 2>/dev/null`
	if [ $? -eq 0 ]; then
		for j in `lpstat -t | grep "device" | tr ' ' '@'`
		do
			qN=`echo $j | tr '@' ' ' | awk -F" " '{print $3}' | awk -F":" '{print $1}'`
			if [ "$qN" = "$qName" ]; then
				echo "Queue $qName is already exist" >> ${log_file}
				flag=1
				break
			fi
		done
		if [ $flag -eq 1 ]; then
			flag=0
			continue
		fi
	else
		echo "No existing print queue found" >> ${log_file}
	fi

	lpadmin -p $qName -E -v "$uri" -m $driver >/dev/null 2>&1
	if [ $? -ne 0 ]; then
		echo "Failed to create queue for $usb" >> ${log_file}
		exit 3;
	fi
	echo "Queue created with name $qName successfully" >> ${log_file}


	lpadmin -d $qName >/dev/null 2>&1
	if [ $? -ne 0 ]; then
		echo "Failed to make queue $qName as default printer" >> ${log_file}
	else
		echo "Queue $qName is become default printer successfully" >> ${log_file}
	fi

	#grep $serialNum srlist.txt > /dev/null 2>&1
	#if [ $? -ne 0 ]; then
	#	echo $serialNum >> srlist.txt
	#else
	#fi

	#echo "#####################################"
done

echo "Leaving qUtil script" >> ${log_file}

exit 0;
